# KF pubsub

Pubsub implementation with redis

## Installation

### With requirements.txt

Add the following line in your `requirements.txt` file:

```
kfpubsub
```

### With PIP

```bash
$ pip install kfpubsub
```
